@@ -4,8 +4,8 @@ use Mojo::Base 'LinkEmbedder::Link';
 use Mojo::JSON;
 use Mojo::Util 'trim';
 
-my $PHOTO_RE = qr!\.(?:jpg|png|gif)\b!i;
-my $VIDEO_RE = qr!\.(?:mpg|mpeg|mov|mp4|ogv)\b!i;
+my $PHOTO_RE = qr!\.(?:jpg|png|gif|webp)\b!i;
+my $VIDEO_RE = qr!\.(?:mpg|mpeg|mov|mp4|ogv|webm)\b!i;
 
 sub learn_p {
   my $self = shift;
@@ -14,6 +14,10 @@ sub learn_p {
 
   $self->type($type);
 
+  if ($type eq 'video' and $url =~ m/\.([^.]+)$/) {
+    $self->mimetype(lc "video/$1");
+  }
+
   return $type eq 'link' ? $self->SUPER::learn_p : Mojo::Promise->new->resolve($self->_learn_from_url);
 }
 
@@ -34,8 +38,8 @@ sub _learn_from_dom {
   }
 
   # Mojopaste, Perlbot and other pages with <pre> tags
-  if ($tmp = $dom->at('pre#paste') || $dom->at('pre.paste') || $dom->at('body > pre') || $dom->at('body > div > pre')) {
-    $self->{paste} = $tmp->text;
+  if ($tmp = $dom->at('pre#paste') || $dom->at('pre.paste') || $dom->at('body > pre') || $dom->at('body > div > pre') || $dom->at('.code')) {
+    $self->{paste} = $tmp->all_text;
     $self->template->[1] = 'paste.html.ep';
   }
 
